/*******************************************************************************
* File Name: SCBUART_PM.c
* Version 1.20
*
* Description:
*  This file provides the source code to the Power Management support for
*  the SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SCBUART.h"
#include "SCBUART_PVT.h"

#if(SCBUART_SCB_MODE_I2C_INC)
    #include "SCBUART_I2C_PVT.h"
#endif /* (SCBUART_SCB_MODE_I2C_INC) */

#if(SCBUART_SCB_MODE_EZI2C_INC)
    #include "SCBUART_EZI2C_PVT.h"
#endif /* (SCBUART_SCB_MODE_EZI2C_INC) */

#if(SCBUART_SCB_MODE_SPI_INC || SCBUART_SCB_MODE_UART_INC)
    #include "SCBUART_SPI_UART_PVT.h"
#endif /* (SCBUART_SCB_MODE_SPI_INC || SCBUART_SCB_MODE_UART_INC) */


/***************************************
*   Backup Structure declaration
***************************************/

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG || \
   (SCBUART_SCB_MODE_I2C_CONST_CFG   && (!SCBUART_I2C_WAKE_ENABLE_CONST))   || \
   (SCBUART_SCB_MODE_EZI2C_CONST_CFG && (!SCBUART_EZI2C_WAKE_ENABLE_CONST)) || \
   (SCBUART_SCB_MODE_SPI_CONST_CFG   && (!SCBUART_SPI_WAKE_ENABLE_CONST))   || \
   (SCBUART_SCB_MODE_UART_CONST_CFG  && (!SCBUART_UART_WAKE_ENABLE_CONST)))

    SCBUART_BACKUP_STRUCT SCBUART_backup =
    {
        0u, /* enableState */
    };
#endif


/*******************************************************************************
* Function Name: SCBUART_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component to enter Deep Sleep.
*  The Enable wakeup from Sleep Mode selection has an influence on
*  this function implementation.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCBUART_Sleep(void)
{
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)

    if(SCBUART_SCB_WAKE_ENABLE_CHECK)
    {
        if(SCBUART_SCB_MODE_I2C_RUNTM_CFG)
        {
            SCBUART_I2CSaveConfig();
        }
        else if(SCBUART_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            SCBUART_EzI2CSaveConfig();
        }
    #if(!SCBUART_CY_SCBIP_V1_I2C_ONLY)
        else if(SCBUART_SCB_MODE_SPI_RUNTM_CFG)
        {
            SCBUART_SpiSaveConfig();
        }
        else if(SCBUART_SCB_MODE_UART_RUNTM_CFG)
        {
            SCBUART_UartSaveConfig();
        }
    #endif /* (!SCBUART_CY_SCBIP_V1_I2C_ONLY) */
        else
        {
            /* Unknown mode: do nothing */
        }
    }
    else
    {
        SCBUART_backup.enableState = (uint8) SCBUART_GET_CTRL_ENABLED;

        if(0u != SCBUART_backup.enableState)
        {
            SCBUART_Stop();
        }
    }

#else

    #if (SCBUART_SCB_MODE_I2C_CONST_CFG && SCBUART_I2C_WAKE_ENABLE_CONST)
        SCBUART_I2CSaveConfig();

    #elif (SCBUART_SCB_MODE_EZI2C_CONST_CFG && SCBUART_EZI2C_WAKE_ENABLE_CONST)
        SCBUART_EzI2CSaveConfig();

    #elif (SCBUART_SCB_MODE_SPI_CONST_CFG && SCBUART_SPI_WAKE_ENABLE_CONST)
        SCBUART_SpiSaveConfig();

    #elif (SCBUART_SCB_MODE_UART_CONST_CFG && SCBUART_UART_WAKE_ENABLE_CONST)
        SCBUART_UartSaveConfig();

    #else

        SCBUART_backup.enableState = (uint8) SCBUART_GET_CTRL_ENABLED;

        if(0u != SCBUART_backup.enableState)
        {
            SCBUART_Stop();
        }

    #endif /* defined (SCBUART_SCB_MODE_I2C_CONST_CFG) && (SCBUART_I2C_WAKE_ENABLE_CONST) */

#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: SCBUART_Wakeup
********************************************************************************
*
* Summary:
*  Prepares the component for the Active mode operation after exiting Deep Sleep.
*  The Enable wakeup from Sleep Mode option has an influence on this function
*  implementation.
*  This function should not be called after exiting Sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCBUART_Wakeup(void)
{
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)

    if(SCBUART_SCB_WAKE_ENABLE_CHECK)
    {
        if(SCBUART_SCB_MODE_I2C_RUNTM_CFG)
        {
            SCBUART_I2CRestoreConfig();
        }
        else if(SCBUART_SCB_MODE_EZI2C_RUNTM_CFG)
        {
            SCBUART_EzI2CRestoreConfig();
        }
    #if(!SCBUART_CY_SCBIP_V1_I2C_ONLY)
        else if(SCBUART_SCB_MODE_SPI_RUNTM_CFG)
        {
            SCBUART_SpiRestoreConfig();
        }
        else if(SCBUART_SCB_MODE_UART_RUNTM_CFG)
        {
            SCBUART_UartRestoreConfig();
        }
    #endif /* (!SCBUART_CY_SCBIP_V1_I2C_ONLY) */
        else
        {
            /* Unknown mode: do nothing */
        }
    }
    else
    {
        if(0u != SCBUART_backup.enableState)
        {
            SCBUART_Enable();
        }
    }

#else

    #if (SCBUART_SCB_MODE_I2C_CONST_CFG  && SCBUART_I2C_WAKE_ENABLE_CONST)
        SCBUART_I2CRestoreConfig();

    #elif (SCBUART_SCB_MODE_EZI2C_CONST_CFG && SCBUART_EZI2C_WAKE_ENABLE_CONST)
        SCBUART_EzI2CRestoreConfig();

    #elif (SCBUART_SCB_MODE_SPI_CONST_CFG && SCBUART_SPI_WAKE_ENABLE_CONST)
        SCBUART_SpiRestoreConfig();

    #elif (SCBUART_SCB_MODE_UART_CONST_CFG && SCBUART_UART_WAKE_ENABLE_CONST)
        SCBUART_UartRestoreConfig();

    #else

        if(0u != SCBUART_backup.enableState)
        {
            SCBUART_Enable();
        }

    #endif /* (SCBUART_I2C_WAKE_ENABLE_CONST) */

#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/* [] END OF FILE */
