/**
 * @file encoder_sw_ir.c
 * @author  Reiner Wehner 
 * @date    09.11.2015 - first implement
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * https://www.gnu.org/copyleft/gpl.html
 *
 * @section software solution for rotary encoder (IR method)
 *
 * @todo
 *
 * @version 1.0
 */

//****************************************************************//
//* includes                                                     *//
//****************************************************************//
#include "encoder_sw_ir.h"

//****************************************************************//
//* global variables                                             *//
//****************************************************************//
ENCODER_t myEncoder = {
    .encoderMode = 0, 
    .counterValue = INITIAL_COUNTER,
    .switchPressed = 0,
    .direction = '-', 
    .sLast = 0,
};

uint32 encScanTimer = 0;

//*****************************************************************//
//* isr functions                                                 *//
//*****************************************************************//

//ButtonInterrupt (if needed)
CY_ISR(isrEncSw){
    myEncoder.switchCount++;       //counter (if needed)
    myEncoder.switchPressed = 1;   //button Flag
}

//isr_ENCA
CY_ISR(isr_ENCA){
    #ifdef DEBUG
       TestA_Write(1);     //debug oszi
    #endif
    read_encoder();        //inline function for read and decode encoder

    #ifdef DEBUG
        TestA_Write(0);    //debug oszi
    #endif
}

//isr_ENCB
CY_ISR(isr_ENCB){
    #ifdef DEBUG
       TestB_Write(1);     //debug oszi
    #endif
    
    read_encoder();        //inline function for read and decode encoder

    #ifdef DEBUG
       TestB_Write(0);     //debug oszi
    #endif
}

//*****************************************************************//
//* base functions                                                *//
//*****************************************************************//

/**
 * Function:    read_encoder
 * Description:
 *     inline function decode gray-code and count encoder detents

 @param         void
 @return        void
*/
inline void read_encoder(void){
    //desable encoder IRs
    isrENCA_falling_Disable();
    isrENCA_rising_Disable();
    isrENCB_falling_Disable();
    isrENCB_rising_Disable();
    
    uint8 encA = ENCA_Read();       //read phase A
    uint8 encB = ENCB_Read();       //read phase B
    uint8 s = encB;                 //stati      
    
    if (encA) {s ^= 3;}             //negate bit0 if bit1 set
    
    s -=  myEncoder.sLast;          //build difference between state ans last state
    if (s & 1) {                    //if bit0 set (diff is 1 or 3) 
        myEncoder.sLast += s;       //s is now s-sLast -> sLast + s – sLast = s
        if (0 == myEncoder.sLast % (1 << myEncoder.encoderMode) ) {  //only the right state (1<<encoderMode) => 0,1,2->1,2,4
            uint32 lastCounterValue = myEncoder.counterValue;
            myEncoder.counterValue += (s & 2) - 1;   //clear bit -> (0 vw; 2 bw)-1 
            myEncoder.direction = (lastCounterValue < myEncoder.counterValue) ? '+':'-'; //encoder direction
        }
    }
    //enable encoder IRs
    isrENCA_falling_Enable();
    isrENCA_rising_Enable();
    isrENCB_falling_Enable();
    isrENCB_rising_Enable();

}

/**
 * Function:    encoder_init
 * Description:
 *     define custom isr  

 @param         void
 @return        void
*/
void encoder_init(){
    //button isr (if needed)
    isrEncSw_StartEx(isrEncSw);
    
    //ENCA isr
    isrENCA_rising_StartEx(isr_ENCA);
    isrENCA_falling_StartEx(isr_ENCA);
    
    //ENCB isr
    isrENCB_rising_StartEx(isr_ENCB);
    isrENCB_falling_StartEx(isr_ENCB);
}    

/**
 * Function:    encoder_update
 * Description:
 *     sample, decode the encoder and update counter  

 @param         void
 @return        void
*/

/* [] END OF FILE */
			